@@ -37,16 +37,17 @@
 #include <sys/file.h>
 #endif
 
-#include "locatestring.h"
 #include "char.h"
 #include "die.h"
+#include "locatestring.h"
+#include "strbuf.h"
 #include "test.h"
 
 /**
  * Decide whether or not the @a path is binary file.
  *
  *	@param[in]	path
- *	@return	0: is not binary, 1: is binary
+ *	@return 0: is not binary, 1: is binary
  */
 static int
 is_binary(const char *path)
@@ -84,8 +85,8 @@ is_binary(const char *path)
  *			@CODE{"x"}	[ -x path ] is @a path an executable file/program? <br>
  *			@CODE{"b"}	[ -b path ] is @a path a binary file?
  *
- *	@param[in]	path	path <br>
- *			if @VAR{NULL} then previous path.
+ *	@param[in]	path	path to test, <br>
+ *			if @VAR{NULL} then use the saved previous path, calls die() if is none.
  *	@return		0: no, 1: ok
  *
  * You can specify more than one character. It assumed 'AND' test.
@@ -94,11 +95,19 @@ int
 test(const char *flags, const char *path)
 {
 	static struct stat sb;
+	STATIC_STRBUF(saved_path);
 	int c;
 
-	if (path != NULL)
+	if (path != NULL) {
 		if (stat(path, &sb) < 0)
 			return 0;
+		strbuf_clear(saved_path);
+		strbuf_puts(saved_path, path);
+	} else {
+		if (strbuf_empty(saved_path))
+			die("no saved previous path [test()]");
+		path = (const char *) strbuf_value(saved_path);
+	}
 	while ((c = *flags++) != 0) {
 		switch (c) {
 		case 'b':
